@@ -140,7 +140,7 @@ udgamma <- function (shape,scale=1,lb=0,ub=Inf) {
 udghyp <- function (lambda,alpha,beta,delta,mu, lb=-Inf,ub=Inf) {
   if (missing (lambda) || missing (alpha) || missing (beta)
       || missing (delta) || missing (mu))
-    stop ("argument 'lambda', 'alpha', 'beta', 'delta', or 'lambda' missing")
+    stop ("argument 'lambda', 'alpha', 'beta', 'delta', or 'mu' missing")
   distr <- new ("unuran.cont",empty=TRUE)
   distr@distr <-.Call("Runuran_std_cont", distr, "ghyp", c(lambda,alpha,beta,delta,mu),
                       c(lb,ub), PACKAGE="Runuran")
@@ -163,6 +163,14 @@ udgig <- function (theta,psi,chi, lb=0,ub=Inf) {
   distr
 }
 
+udgiga <- function (theta,omega,eta=1, lb=0,ub=Inf) {
+  if (missing (theta) || missing (omega) )
+    stop ("argument 'theta' or 'omega' missing")
+  distr <- new ("unuran.cont",empty=TRUE)
+  distr@distr <-.Call("Runuran_std_cont", distr, "gig", c(theta,omega,eta), c(lb,ub), PACKAGE="Runuran")
+  distr
+}
+
 ## -- Gumbel (Extreme Value type I) distribution ----------------------------
 urextremeI <- function (n,location=0,scale=1,lb=-Inf,ub=Inf) {
         unr <- new("unuran", paste("extremeI(",location,",",scale,"); domain=(",lb,",",ub,")"), "HINV")
@@ -249,6 +257,16 @@ udlomax <- function (shape,scale=1,lb=0,ub=Inf) {
   distr
 }
 
+## -- Meixner distribution --------------------------------------------------
+udmeixner <- function (alpha,beta,delta,mu, lb=-Inf,ub=Inf) {
+  if (missing (alpha) || missing (beta) || missing (delta) || missing (mu))
+    stop ("argument 'alpha', 'beta', 'delta', or 'mu' missing")
+  distr <- new ("unuran.cont",empty=TRUE)
+  distr@distr <-.Call("Runuran_std_cont", distr, "meixner", c(alpha,beta,delta,mu),
+                      c(lb,ub), PACKAGE="Runuran")
+  distr
+}
+
 ## -- Normal (Gaussian) distribution - (replacement for rnorm) --------------
 urnorm <- function (n,mean=0,sd=1,lb=-Inf,ub=Inf) {
         unr<-new("unuran",paste("normal(",mean,",",sd,"); domain=(",lb,",",ub,")"),"HINV")
@@ -356,6 +374,16 @@ urtriang <- function (n,a,m,b,lb=a,ub=b) {
 #}
 ## TODO
 
+## -- Variance gamma distribution -------------------------------------------
+udvg <- function (lambda, alpha, beta, mu, lb=-Inf, ub=Inf) {
+  if (missing (lambda) || missing (alpha) || missing (beta) || missing (mu))
+    stop ("argument 'lambda', 'alpha', 'beta', or 'mu' missing")
+  distr <- new ("unuran.cont",empty=TRUE)
+  distr@distr <-.Call("Runuran_std_cont", distr, "vg", c(lambda,alpha,beta,mu),
+                      c(lb,ub), PACKAGE="Runuran")
+  distr
+}
+
 ## -- Weibull distribution - (replacement for rweibull) ---------------------
 urweibull <- function (n,shape,scale=1,lb=0,ub=Inf) {
         unr <- new("unuran", paste("weibull(",shape,",",scale,"); domain=(",lb,",",ub,")"), "HINV")
